@@ -42,6 +42,7 @@ use crate::{Api,
      GetStudentByIdResponse,
      GetStudentsResponse
      };
+use chrono::NaiveDate;
 
 /// Convert input into a base path, e.g. "http://example:123". Also checks the scheme as it goes.
 fn into_base_path(input: impl TryInto<Uri, Error=hyper::http::uri::InvalidUri>, correct_scheme: Option<&'static str>) -> Result<String, ClientInitError> {
@@ -827,7 +828,7 @@ impl<S, C> Api<C> for Client<S, C> where
         param_email: Option<String>,
         param_phone: Option<String>,
         param_undergraduate_school: Option<String>,
-        param_date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+        param_date_of_birth: Option<NaiveDate>,
         param_place_of_birth: Option<String>,
         param_polity_name: Option<String>,
         param_specialism: Option<String>,
