@@ -13,7 +13,7 @@ use crate::header;
 #[repr(C)]
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
-pub enum EducationalStage {
+pub enum EducationalLevel {
     #[serde(rename = "ELEMENTARY_SCHOOL")]
     ELEMENTARY_SCHOOL,
     #[serde(rename = "MIDDLE_SCHOOL")]
@@ -26,28 +26,372 @@ pub enum EducationalStage {
     MASTER,
 }
 
-impl std::fmt::Display for EducationalStage {
+impl std::fmt::Display for EducationalLevel {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match *self {
-            EducationalStage::ELEMENTARY_SCHOOL => write!(f, "{}", "ELEMENTARY_SCHOOL"),
-            EducationalStage::MIDDLE_SCHOOL => write!(f, "{}", "MIDDLE_SCHOOL"),
-            EducationalStage::HIGH_SCHOOL => write!(f, "{}", "HIGH_SCHOOL"),
-            EducationalStage::BACHELOR => write!(f, "{}", "BACHELOR"),
-            EducationalStage::MASTER => write!(f, "{}", "MASTER"),
+            EducationalLevel::ELEMENTARY_SCHOOL => write!(f, "{}", "ELEMENTARY_SCHOOL"),
+            EducationalLevel::MIDDLE_SCHOOL => write!(f, "{}", "MIDDLE_SCHOOL"),
+            EducationalLevel::HIGH_SCHOOL => write!(f, "{}", "HIGH_SCHOOL"),
+            EducationalLevel::BACHELOR => write!(f, "{}", "BACHELOR"),
+            EducationalLevel::MASTER => write!(f, "{}", "MASTER"),
         }
     }
 }
 
-impl std::str::FromStr for EducationalStage {
+impl std::str::FromStr for EducationalLevel {
     type Err = String;
 
     fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
         match s {
-            "ELEMENTARY_SCHOOL" => std::result::Result::Ok(EducationalStage::ELEMENTARY_SCHOOL),
-            "MIDDLE_SCHOOL" => std::result::Result::Ok(EducationalStage::MIDDLE_SCHOOL),
-            "HIGH_SCHOOL" => std::result::Result::Ok(EducationalStage::HIGH_SCHOOL),
-            "BACHELOR" => std::result::Result::Ok(EducationalStage::BACHELOR),
-            "MASTER" => std::result::Result::Ok(EducationalStage::MASTER),
+            "ELEMENTARY_SCHOOL" => std::result::Result::Ok(EducationalLevel::ELEMENTARY_SCHOOL),
+            "MIDDLE_SCHOOL" => std::result::Result::Ok(EducationalLevel::MIDDLE_SCHOOL),
+            "HIGH_SCHOOL" => std::result::Result::Ok(EducationalLevel::HIGH_SCHOOL),
+            "BACHELOR" => std::result::Result::Ok(EducationalLevel::BACHELOR),
+            "MASTER" => std::result::Result::Ok(EducationalLevel::MASTER),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
+
+#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
+pub struct EducationalStage {
+    #[serde(rename = "educationalLevel")]
+    pub educational_level: models::EducationalLevel,
+
+    #[serde(rename = "schoolName")]
+    pub school_name: String,
+
+    #[serde(rename = "major")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub major: Option<String>,
+
+    #[serde(rename = "graduateYear")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub graduate_year: Option<f64>,
+
+}
+
+impl EducationalStage {
+    pub fn new(educational_level: models::EducationalLevel, school_name: String, ) -> EducationalStage {
+        EducationalStage {
+            educational_level: educational_level,
+            school_name: school_name,
+            major: None,
+            graduate_year: None,
+        }
+    }
+}
+
+/// Converts the EducationalStage value to the Query Parameters representation (style=form, explode=false)
+/// specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde serializer
+impl std::string::ToString for EducationalStage {
+    fn to_string(&self) -> String {
+        let mut params: Vec<String> = vec![];
+        // Skipping educationalLevel in query parameter serialization
+
+
+        params.push("schoolName".to_string());
+        params.push(self.school_name.to_string());
+
+
+        if let Some(ref major) = self.major {
+            params.push("major".to_string());
+            params.push(major.to_string());
+        }
+
+
+        if let Some(ref graduate_year) = self.graduate_year {
+            params.push("graduateYear".to_string());
+            params.push(graduate_year.to_string());
+        }
+
+        params.join(",").to_string()
+    }
+}
+
+/// Converts Query Parameters representation (style=form, explode=false) to a EducationalStage value
+/// as specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde deserializer
+impl std::str::FromStr for EducationalStage {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        #[derive(Default)]
+        // An intermediate representation of the struct to use for parsing.
+        struct IntermediateRep {
+            pub educational_level: Vec<models::EducationalLevel>,
+            pub school_name: Vec<String>,
+            pub major: Vec<String>,
+            pub graduate_year: Vec<f64>,
+        }
+
+        let mut intermediate_rep = IntermediateRep::default();
+
+        // Parse into intermediate representation
+        let mut string_iter = s.split(',').into_iter();
+        let mut key_result = string_iter.next();
+
+        while key_result.is_some() {
+            let val = match string_iter.next() {
+                Some(x) => x,
+                None => return std::result::Result::Err("Missing value while parsing EducationalStage".to_string())
+            };
+
+            if let Some(key) = key_result {
+                match key {
+                    "educationalLevel" => intermediate_rep.educational_level.push(<models::EducationalLevel as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "schoolName" => intermediate_rep.school_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "major" => intermediate_rep.major.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "graduateYear" => intermediate_rep.graduate_year.push(<f64 as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    _ => return std::result::Result::Err("Unexpected key while parsing EducationalStage".to_string())
+                }
+            }
+
+            // Get the next key
+            key_result = string_iter.next();
+        }
+
+        // Use the intermediate representation to return the struct
+        std::result::Result::Ok(EducationalStage {
+            educational_level: intermediate_rep.educational_level.into_iter().next().ok_or("educationalLevel missing in EducationalStage".to_string())?,
+            school_name: intermediate_rep.school_name.into_iter().next().ok_or("schoolName missing in EducationalStage".to_string())?,
+            major: intermediate_rep.major.into_iter().next(),
+            graduate_year: intermediate_rep.graduate_year.into_iter().next(),
+        })
+    }
+}
+
+// Methods for converting between header::IntoHeaderValue<EducationalStage> and hyper::header::HeaderValue
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<header::IntoHeaderValue<EducationalStage>> for hyper::header::HeaderValue {
+    type Error = String;
+
+    fn try_from(hdr_value: header::IntoHeaderValue<EducationalStage>) -> std::result::Result<Self, Self::Error> {
+        let hdr_value = hdr_value.to_string();
+        match hyper::header::HeaderValue::from_str(&hdr_value) {
+             std::result::Result::Ok(value) => std::result::Result::Ok(value),
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Invalid header value for EducationalStage - value: {} is invalid {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderValue<EducationalStage> {
+    type Error = String;
+
+    fn try_from(hdr_value: hyper::header::HeaderValue) -> std::result::Result<Self, Self::Error> {
+        match hdr_value.to_str() {
+             std::result::Result::Ok(value) => {
+                    match <EducationalStage as std::str::FromStr>::from_str(value) {
+                        std::result::Result::Ok(value) => std::result::Result::Ok(header::IntoHeaderValue(value)),
+                        std::result::Result::Err(err) => std::result::Result::Err(
+                            format!("Unable to convert header value '{}' into EducationalStage - {}",
+                                value, err))
+                    }
+             },
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Unable to convert header: {:?} to string: {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+
+#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
+pub struct ForeignLanguage {
+    #[serde(rename = "language")]
+    pub language: String,
+
+    #[serde(rename = "level")]
+    pub level: models::ForeignLanguageLevel,
+
+}
+
+impl ForeignLanguage {
+    pub fn new(language: String, level: models::ForeignLanguageLevel, ) -> ForeignLanguage {
+        ForeignLanguage {
+            language: language,
+            level: level,
+        }
+    }
+}
+
+/// Converts the ForeignLanguage value to the Query Parameters representation (style=form, explode=false)
+/// specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde serializer
+impl std::string::ToString for ForeignLanguage {
+    fn to_string(&self) -> String {
+        let mut params: Vec<String> = vec![];
+
+        params.push("language".to_string());
+        params.push(self.language.to_string());
+
+        // Skipping level in query parameter serialization
+
+        params.join(",").to_string()
+    }
+}
+
+/// Converts Query Parameters representation (style=form, explode=false) to a ForeignLanguage value
+/// as specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde deserializer
+impl std::str::FromStr for ForeignLanguage {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        #[derive(Default)]
+        // An intermediate representation of the struct to use for parsing.
+        struct IntermediateRep {
+            pub language: Vec<String>,
+            pub level: Vec<models::ForeignLanguageLevel>,
+        }
+
+        let mut intermediate_rep = IntermediateRep::default();
+
+        // Parse into intermediate representation
+        let mut string_iter = s.split(',').into_iter();
+        let mut key_result = string_iter.next();
+
+        while key_result.is_some() {
+            let val = match string_iter.next() {
+                Some(x) => x,
+                None => return std::result::Result::Err("Missing value while parsing ForeignLanguage".to_string())
+            };
+
+            if let Some(key) = key_result {
+                match key {
+                    "language" => intermediate_rep.language.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "level" => intermediate_rep.level.push(<models::ForeignLanguageLevel as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    _ => return std::result::Result::Err("Unexpected key while parsing ForeignLanguage".to_string())
+                }
+            }
+
+            // Get the next key
+            key_result = string_iter.next();
+        }
+
+        // Use the intermediate representation to return the struct
+        std::result::Result::Ok(ForeignLanguage {
+            language: intermediate_rep.language.into_iter().next().ok_or("language missing in ForeignLanguage".to_string())?,
+            level: intermediate_rep.level.into_iter().next().ok_or("level missing in ForeignLanguage".to_string())?,
+        })
+    }
+}
+
+// Methods for converting between header::IntoHeaderValue<ForeignLanguage> and hyper::header::HeaderValue
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<header::IntoHeaderValue<ForeignLanguage>> for hyper::header::HeaderValue {
+    type Error = String;
+
+    fn try_from(hdr_value: header::IntoHeaderValue<ForeignLanguage>) -> std::result::Result<Self, Self::Error> {
+        let hdr_value = hdr_value.to_string();
+        match hyper::header::HeaderValue::from_str(&hdr_value) {
+             std::result::Result::Ok(value) => std::result::Result::Ok(value),
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Invalid header value for ForeignLanguage - value: {} is invalid {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderValue<ForeignLanguage> {
+    type Error = String;
+
+    fn try_from(hdr_value: hyper::header::HeaderValue) -> std::result::Result<Self, Self::Error> {
+        match hdr_value.to_str() {
+             std::result::Result::Ok(value) => {
+                    match <ForeignLanguage as std::str::FromStr>::from_str(value) {
+                        std::result::Result::Ok(value) => std::result::Result::Ok(header::IntoHeaderValue(value)),
+                        std::result::Result::Err(err) => std::result::Result::Err(
+                            format!("Unable to convert header value '{}' into ForeignLanguage - {}",
+                                value, err))
+                    }
+             },
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Unable to convert header: {:?} to string: {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum ForeignLanguageLevel {
+    #[serde(rename = "BEGINNER")]
+    BEGINNER,
+    #[serde(rename = "INTERMEDIATE")]
+    INTERMEDIATE,
+    #[serde(rename = "ADVANCED")]
+    ADVANCED,
+}
+
+impl std::fmt::Display for ForeignLanguageLevel {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            ForeignLanguageLevel::BEGINNER => write!(f, "{}", "BEGINNER"),
+            ForeignLanguageLevel::INTERMEDIATE => write!(f, "{}", "INTERMEDIATE"),
+            ForeignLanguageLevel::ADVANCED => write!(f, "{}", "ADVANCED"),
+        }
+    }
+}
+
+impl std::str::FromStr for ForeignLanguageLevel {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "BEGINNER" => std::result::Result::Ok(ForeignLanguageLevel::BEGINNER),
+            "INTERMEDIATE" => std::result::Result::Ok(ForeignLanguageLevel::INTERMEDIATE),
+            "ADVANCED" => std::result::Result::Ok(ForeignLanguageLevel::ADVANCED),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
+
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum IdNumberProvider {
+    #[serde(rename = "NATIONAL_ID")]
+    NATIONAL_ID,
+    #[serde(rename = "PASSPORT")]
+    PASSPORT,
+}
+
+impl std::fmt::Display for IdNumberProvider {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            IdNumberProvider::NATIONAL_ID => write!(f, "{}", "NATIONAL_ID"),
+            IdNumberProvider::PASSPORT => write!(f, "{}", "PASSPORT"),
+        }
+    }
+}
+
+impl std::str::FromStr for IdNumberProvider {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "NATIONAL_ID" => std::result::Result::Ok(IdNumberProvider::NATIONAL_ID),
+            "PASSPORT" => std::result::Result::Ok(IdNumberProvider::PASSPORT),
             _ => std::result::Result::Err(format!("Value not valid: {}", s)),
         }
     }
@@ -213,17 +557,17 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub address: Option<String>,
 
-    #[serde(rename = "undergraduateSchool")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub undergraduate_school: Option<String>,
-
     #[serde(rename = "nationality")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub nationality: Option<String>,
 
-    #[serde(rename = "EducationalStage")]
+    #[serde(rename = "educationalStage")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub educational_stage: Option<models::EducationalStage>,
+    pub educational_stage: Option<Vec<models::EducationalStage>>,
+
+    #[serde(rename = "foreignLanguage")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub foreign_language: Option<Vec<models::ForeignLanguage>>,
 
     #[serde(rename = "race")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -233,25 +577,25 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub program_id: Option<uuid::Uuid>,
 
-    #[serde(rename = "isMale")]
+    #[serde(rename = "idNumber")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub is_male: Option<bool>,
+    pub id_number: Option<String>,
 
-    #[serde(rename = "nationalId")]
+    #[serde(rename = "idNumberProvider")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub national_id: Option<String>,
+    pub id_number_provider: Option<models::IdNumberProvider>,
 
     #[serde(rename = "passport")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub passport: Option<String>,
 
-    #[serde(rename = "DateOfIssue")]
+    #[serde(rename = "dateOfIssue")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub date_of_issue: Option<NaiveDate>,
 
-    #[serde(rename = "PlaceOfIssue")]
+    #[serde(rename = "placeOfIssue")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub place_of_issue: Option<NaiveDate>,
+    pub place_of_issue: Option<String>,
 
 }
 
@@ -270,13 +614,13 @@ impl StudentUpsert {
             email: None,
             phone: None,
             address: None,
-            undergraduate_school: None,
             nationality: Some("Vietnamese".to_string()),
             educational_stage: None,
+            foreign_language: None,
             race: None,
             program_id: None,
-            is_male: Some(true),
-            national_id: None,
+            id_number: None,
+            id_number_provider: None,
             passport: None,
             date_of_issue: None,
             place_of_issue: None,
@@ -343,18 +687,14 @@ impl std::string::ToString for StudentUpsert {
         }
 
 
-        if let Some(ref undergraduate_school) = self.undergraduate_school {
-            params.push("undergraduateSchool".to_string());
-            params.push(undergraduate_school.to_string());
-        }
-
-
         if let Some(ref nationality) = self.nationality {
             params.push("nationality".to_string());
             params.push(nationality.to_string());
         }
 
-        // Skipping EducationalStage in query parameter serialization
+        // Skipping educationalStage in query parameter serialization
+
+        // Skipping foreignLanguage in query parameter serialization
 
 
         if let Some(ref race) = self.race {
@@ -365,16 +705,12 @@ impl std::string::ToString for StudentUpsert {
         // Skipping programId in query parameter serialization
 
 
-        if let Some(ref is_male) = self.is_male {
-            params.push("isMale".to_string());
-            params.push(is_male.to_string());
+        if let Some(ref id_number) = self.id_number {
+            params.push("idNumber".to_string());
+            params.push(id_number.to_string());
         }
 
-
-        if let Some(ref national_id) = self.national_id {
-            params.push("nationalId".to_string());
-            params.push(national_id.to_string());
-        }
+        // Skipping idNumberProvider in query parameter serialization
 
 
         if let Some(ref passport) = self.passport {
@@ -382,9 +718,13 @@ impl std::string::ToString for StudentUpsert {
             params.push(passport.to_string());
         }
 
-        // Skipping DateOfIssue in query parameter serialization
+        // Skipping dateOfIssue in query parameter serialization
 
-        // Skipping PlaceOfIssue in query parameter serialization
+
+        if let Some(ref place_of_issue) = self.place_of_issue {
+            params.push("placeOfIssue".to_string());
+            params.push(place_of_issue.to_string());
+        }
 
         params.join(",").to_string()
     }
@@ -412,16 +752,16 @@ impl std::str::FromStr for StudentUpsert {
             pub email: Vec<String>,
             pub phone: Vec<String>,
             pub address: Vec<String>,
-            pub undergraduate_school: Vec<String>,
             pub nationality: Vec<String>,
-            pub educational_stage: Vec<models::EducationalStage>,
+            pub educational_stage: Vec<Vec<models::EducationalStage>>,
+            pub foreign_language: Vec<Vec<models::ForeignLanguage>>,
             pub race: Vec<String>,
             pub program_id: Vec<uuid::Uuid>,
-            pub is_male: Vec<bool>,
-            pub national_id: Vec<String>,
+            pub id_number: Vec<String>,
+            pub id_number_provider: Vec<models::IdNumberProvider>,
             pub passport: Vec<String>,
             pub date_of_issue: Vec<NaiveDate>,
-            pub place_of_issue: Vec<NaiveDate>,
+            pub place_of_issue: Vec<String>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -450,16 +790,16 @@ impl std::str::FromStr for StudentUpsert {
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "address" => intermediate_rep.address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "undergraduateSchool" => intermediate_rep.undergraduate_school.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "nationality" => intermediate_rep.nationality.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "EducationalStage" => intermediate_rep.educational_stage.push(<models::EducationalStage as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "educationalStage" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
+                    "foreignLanguage" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
                     "race" => intermediate_rep.race.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "programId" => intermediate_rep.program_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "isMale" => intermediate_rep.is_male.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "nationalId" => intermediate_rep.national_id.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "idNumber" => intermediate_rep.id_number.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "idNumberProvider" => intermediate_rep.id_number_provider.push(<models::IdNumberProvider as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "passport" => intermediate_rep.passport.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "DateOfIssue" => intermediate_rep.date_of_issue.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "PlaceOfIssue" => intermediate_rep.place_of_issue.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "dateOfIssue" => intermediate_rep.date_of_issue.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "placeOfIssue" => intermediate_rep.place_of_issue.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing StudentUpsert".to_string())
                 }
             }
@@ -482,13 +822,13 @@ impl std::str::FromStr for StudentUpsert {
             email: intermediate_rep.email.into_iter().next(),
             phone: intermediate_rep.phone.into_iter().next(),
             address: intermediate_rep.address.into_iter().next(),
-            undergraduate_school: intermediate_rep.undergraduate_school.into_iter().next(),
             nationality: intermediate_rep.nationality.into_iter().next(),
             educational_stage: intermediate_rep.educational_stage.into_iter().next(),
+            foreign_language: intermediate_rep.foreign_language.into_iter().next(),
             race: intermediate_rep.race.into_iter().next(),
             program_id: intermediate_rep.program_id.into_iter().next(),
-            is_male: intermediate_rep.is_male.into_iter().next(),
-            national_id: intermediate_rep.national_id.into_iter().next(),
+            id_number: intermediate_rep.id_number.into_iter().next(),
+            id_number_provider: intermediate_rep.id_number_provider.into_iter().next(),
             passport: intermediate_rep.passport.into_iter().next(),
             date_of_issue: intermediate_rep.date_of_issue.into_iter().next(),
             place_of_issue: intermediate_rep.place_of_issue.into_iter().next(),
